@@ -10,12 +10,14 @@ import PropTypes from 'prop-types';
 import reject from 'lodash/reject';
 import find from 'lodash/find';
 import { InputGroup, Input, Icon } from 'native-base';
+import * as Animatable from 'react-native-animatable';
 import IconMd from 'react-native-vector-icons/MaterialIcons';
 
 import styles, { colorPack } from './styles';
 
 export default class MultiSelect extends Component {
   static propTypes = {
+    animate: PropTypes.bool,
     single: PropTypes.bool,
     selectedItems: PropTypes.array,
     items: PropTypes.array.isRequired,
@@ -39,6 +41,7 @@ export default class MultiSelect extends Component {
   };
 
   static defaultProps = {
+    animate: false,
     single: false,
     selectedItems: [],
     items: [],
@@ -80,7 +83,7 @@ export default class MultiSelect extends Component {
       const item = selectedItems[0];
       return item.name;
     }
-    return `${selectText} ${selectedItems.length} selected`;
+    return `${selectText} (${selectedItems.length} selected)`;
   };
 
   _displaySelectedItems = () => {
@@ -319,6 +322,7 @@ export default class MultiSelect extends Component {
   render() {
     const {
       single,
+      animate,
       fontFamily, 
       altFontFamily,
       searchInputPlaceholderText,
@@ -338,45 +342,50 @@ export default class MultiSelect extends Component {
           this.state.selector
           ?
             <View style={styles.selectorView}>
-              <InputGroup
-                style={{
-                  paddingLeft: 16,
-                  backgroundColor: colorPack.light,
-                }}
-              >
-                <Icon
-                  name="ios-search"
-                  style={{ fontSize: 20, color: colorPack.placeholderTextColor }}
-                />
-                <Input
-                  onChangeText={searchTerm => this.setState({ searchTerm })}
-                  placeholder={searchInputPlaceholderText}
-                  placeholderTextColor={colorPack.placeholderTextColor}
-                  style={searchInputStyle}
-                />
-              </InputGroup>
-              <View
+              <View>
+                <InputGroup
+                  style={{
+                    paddingLeft: 16,
+                    backgroundColor: colorPack.light,
+                  }}
+                >
+                  <Icon
+                    name="ios-search"
+                    style={{ fontSize: 20, color: colorPack.placeholderTextColor }}
+                  />
+                  <Input
+                    onChangeText={searchTerm => this.setState({ searchTerm })}
+                    placeholder={searchInputPlaceholderText}
+                    placeholderTextColor={colorPack.placeholderTextColor}
+                    style={searchInputStyle}
+                  />
+                </InputGroup>
+              </View>
+              <Animatable.View 
+                animation={animate ? 'slideInDown' : null}
                 style={{
                   flex: 1,
                   flexDirection: 'column',
                   backgroundColor: '#fafafa',
                 }}
               >
-                {this._renderItems()}
-              </View>
-              {
-                !single && 
-                <TouchableOpacity
-                  onPress={() => this._submitSelection()}
-                  style={[styles.button, { backgroundColor: submitButtonColor }]}
-                >
-                  <Text
-                    style={[styles.buttonText, fontFamily ? { fontFamily } : {}]}
+                <View style={{ flex: 1 }}>
+                  {this._renderItems()}
+                </View>
+                {
+                  !single && 
+                  <TouchableOpacity
+                    onPress={() => this._submitSelection()}
+                    style={[styles.button, { backgroundColor: submitButtonColor }]}
                   >
-                    {submitButtonText}
-                  </Text>
-                </TouchableOpacity>
-              }
+                    <Text
+                      style={[styles.buttonText, fontFamily ? { fontFamily } : {}]}
+                    >
+                      {submitButtonText}
+                    </Text>
+                  </TouchableOpacity>
+                }
+              </Animatable.View>
             </View>
             :
             <View>
